==> foundation-ui-components-1.8.1.tgz: package/src/common/card/NsCheckoutCard.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { NsIcon, NsIconNameType, NsLink } from '../';
import { useState } from 'react';

type NsCheckoutCardProps = {
    icon: NsIconNameType;
    title: string;
    address: string;
    onClick: () => void;
};

const CardContainer = styled(Box)(() => {
    return {
        backgroundColor: '#fff',
        display: 'flex',
        width: '345px',
        height: 'auto',
        border: '2px solid #B2B2B2',
        borderRadius: '2px',
        '.left-bar': {
            width: '4px',
            height: 'auto',
            backgroundColor: '#22D55C',
        },
        '.content': {
            display: 'flex',
            flexDirection: 'row',
            gap: '10px',
            margin: '10px',
            width: '100%',
        },
        '.text-content': {
            width: '100%',
        },
        '.title': {
            fontSize: '14px',
            fontWeight: '700',
        },
        '.address': {
            fontSize: '13px',
            fontWeight: '400',
        },
        '.action-link': {
            color: '#7123D9',
            fontSize: '14px',
            fontWeight: '700',
            letterSpacing: '0.7',
        },
        '.icon-right': {
            marginLeft: 'auto',
        },
        '.icon': {
            ':hover': {
                cursor: 'pointer',
            },
        },
    };
});

export default function NsCheckoutCard({ title, address, icon, onClick }: NsCheckoutCardProps) {
    const [dropdownIcon, setDropdownIcon] = useState(false);
    const handleClick = () => {
        setDropdownIcon(!dropdownIcon);
    };

    return (
        <CardContainer role="checkout-card" component="div" data-testid="checkout-card" onClick={onClick}>
            <div className="left-bar"></div>
            <div className="content">
                <span>
                    <NsIcon name={icon} />
                </span>
                <div className="text-content">
                    <article className="title">{title}</article>
                    <article className="address">{address}</article>
                    <NsLink className="action-link" href={''}>
                        CHANGE
                    </NsLink>
                </div>
                <span className="icon-right">
                    <NsIcon
                        name={dropdownIcon ? 'arrowUp' : 'arrowDown'}
                        className="icon"
                        onClick={handleClick}
                        testId="dropdown-icon"
                    />
                </span>
            </div>
        </CardContainer>
    );
}

==> foundation-ui-components-1.15.0.tgz: package/src/common/card/NsCheckoutCard.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { NsIcon, NsIconNameType, NsLink } from '../';
import { useState } from 'react';

type NsCheckoutCardProps = {
    icon: NsIconNameType;
    title: string;
    linkText: string;
    url: string;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        backgroundColor: '#fff',
        display: 'flex',
        width: '345px',
        height: 'auto',
        border: '2px solid #B2B2B2',
        borderRadius: '2px',
        '.left-bar': {
            width: '4px',
            height: 'auto',
            backgroundColor: '#22D55C',
        },
        '.content': {
            display: 'flex',
            flexDirection: 'row',
            gap: '10px',
            margin: '10px',
            width: '100%',
        },
        '.text-content': {
            width: '100%',
        },
        '.title': {
            fontSize: '14px',
            fontWeight: '700',
        },
        '.address': {
            fontSize: '13px',
            fontWeight: '400',
        },
        '.action-link': {
            color: '#7123D9',
            fontSize: '14px',
            fontWeight: '700',
            letterSpacing: '0.7',
        },
        '.icon-right': {
            marginLeft: 'auto',
        },
        '.icon': {
            ':hover': {
                cursor: 'pointer',
            },
        },
    };
});

export default function NsCheckoutCard({ title, icon, linkText, url, className }: NsCheckoutCardProps) {
    const [dropdownIcon, setDropdownIcon] = useState(false);
    const handleClick = () => {
        setDropdownIcon(!dropdownIcon);
    };

    return (
        <CardContainer className={className} role="checkout-card" component="div" data-testid="checkout-card">
            <div className="left-bar"></div>
            <div className="content">
                <span>
                    <NsIcon name={icon} />
                </span>
                <div className="text-content">
                    <article className="title">{title}</article>
                    <article className="address">Address</article>
                    <NsLink className="action-link" href={url}>
                        {linkText}
                    </NsLink>
                </div>
                <span className="icon-right">
                    <NsIcon
                        name={dropdownIcon ? 'arrowUp' : 'arrowDown'}
                        className="icon"
                        onClick={handleClick}
                        testId="dropdown-icon"
                    />
                </span>
            </div>
        </CardContainer>
    );
}
